package database

import (
	"database/sql"

	"git.linuxforward.com/byom/byom-golang-lib/pkg/errors"
	_ "github.com/mattn/go-sqlite3"
)

type SQLiteConfig struct {
	Path string
}

func NewSQLiteDB(config SQLiteConfig) (*sql.DB, error) {
	db, err := sql.Open("sqlite3", config.Path)
	if err != nil {
		return nil, errors.NewDatabaseError("open", err)
	}

	// Test connection
	if err := db.Ping(); err != nil {
		return nil, errors.NewDatabaseError("ping", err)
	}

	// Set connection pool settings
	db.SetMaxOpenConns(1) // SQLite supports only one writer at a time
	db.SetMaxIdleConns(1)

	return db, nil
}
